@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
 
@@ -9,16 +10,16 @@ func BitBucketClientID() *config.Rule {
 	r := config.Rule{
 		Description: "BitBucket Client ID",
 		RuleID:      "bitbucket-client-id",
-		Regex:       generateSemiGenericRegex([]string{"bitbucket"}, alphaNumeric32),
+		Regex:       generateSemiGenericRegex([]string{"bitbucket"}, alphaNumeric("32")),
 		SecretGroup: 1,
 		Keywords:    []string{"bitbucket"},
 	}
 
 	// validate
 	tps := []string{
-		"bitbucket := \"" + sampleAlphaNumeric32Token + "\"",
+		generateSampleSecret("bitbucket", secrets.NewSecret(alphaNumeric("32"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
 
 func BitBucketClientSecret() *config.Rule {
@@ -26,14 +27,14 @@ func BitBucketClientSecret() *config.Rule {
 	r := config.Rule{
 		Description: "BitBucket Client Secret",
 		RuleID:      "bitbucket-client-secret",
-		Regex:       generateSemiGenericRegex([]string{"bitbucket"}, extendedAlphaNumeric64),
+		Regex:       generateSemiGenericRegex([]string{"bitbucket"}, alphaNumericExtended("64")),
 		SecretGroup: 1,
 		Keywords:    []string{"bitbucket"},
 	}
 
 	// validate
 	tps := []string{
-		"bitbucket := \"" + sampleExtendedAlphaNumeric64Token + "\"",
+		generateSampleSecret("bitbucket", secrets.NewSecret(alphaNumeric("64"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
