@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
 
@@ -9,16 +10,16 @@ func DropBoxAPISecret() *config.Rule {
 	r := config.Rule{
 		Description: "Dropbox API secret",
 		RuleID:      "doppler-api-token",
-		Regex:       generateSemiGenericRegex([]string{"dropbox"}, alphaNumeric15),
+		Regex:       generateSemiGenericRegex([]string{"dropbox"}, alphaNumeric("15")),
 		SecretGroup: 1,
 		Keywords:    []string{"dropbox"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("dropbox", sampleAlphaNumeric15Token),
+		generateSampleSecret("dropbox", secrets.NewSecret(alphaNumeric("15"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
 
 func DropBoxShortLivedAPIToken() *config.Rule {
