@@ -11,7 +11,7 @@ func GenericCredential() *config.Rule {
 		Description: "Generic API Key",
 		Regex: generateSemiGenericRegex([]string{
 			"key",
-			"api[^Version]",
+			"api",
 			"token",
 			"secret",
 			"client",
@@ -45,6 +45,9 @@ func GenericCredential() *config.Rule {
 	}
 	fps := []string{
 		`client_vpn_endpoint_id = aws_ec2_client_vpn_endpoint.client-vpn-endpoint.id`,
+		`password combination.
+
+R5: Regulatory--21`,
 	}
 	return validate(r, tps, fps)
 }
